@@ -3,6 +3,7 @@ import aporia.experimental  # noqa: F401
 from .core.core_api import create_model, create_model_version, delete_model, init, shutdown
 from .core.model_tags import add_model_tags, delete_model_tag, get_model_tags
 from .core.types.model import ModelColor, ModelIcon
+from .core.utils import generate_features_schema_from_shape
 from .model import Model
 
 __all__ = [
@@ -17,6 +18,7 @@ __all__ = [
     "get_model_tags",
     "ModelColor",
     "ModelIcon",
+    "generate_features_schema_from_shape",
     # Inference
     "Model",
 ]
