@@ -1,5 +1,5 @@
 import logging
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, Union
 
 from aporia.core.errors import AporiaError
 from aporia.core.http_client import HttpClient
@@ -20,6 +20,8 @@ async def run_create_model_version_query(
     predictions: Dict[str, str],
     raw_inputs: Optional[Dict[str, str]] = None,
     metrics: Optional[Dict[str, str]] = None,
+    model_data_type: Optional[str] = None,
+    multiclass_labels: Optional[List[str]] = None,
 ):
     """Defines the schema for a specific model version.
 
@@ -32,6 +34,8 @@ async def run_create_model_version_query(
         predictions: Prediction fields
         raw_inputs: Raw input fields.
         metrics: Prediction metric fields.
+        model_data_type: Model data type.
+        multiclass_labels: Labels of multiclass or binary model
     """
     query = """
         mutation CreateModelVersion(
@@ -42,15 +46,19 @@ async def run_create_model_version_query(
             $predictions: [Field]!,
             $rawInputs: [Field],
             $metrics: [Field]
+            $modelDataType: String
+            $multiclassLabels: [String]
         ) {
             createModelVersion(
                 modelId: $modelId,
                 modelVersion: $modelVersion,
                 modelType: $modelType,
+                modelDataType: $modelDataType
                 features: $features,
                 predictions: $predictions
                 rawInputs: $rawInputs,
-                metrics: $metrics
+                metrics: $metrics,
+                multiclassLabels: $multiclassLabels
             ) {
                 warnings
             }
@@ -61,10 +69,12 @@ async def run_create_model_version_query(
         "modelId": model_id,
         "modelVersion": model_version,
         "modelType": model_type,
-        "features": prepare_fields(features),
+        "features": prepare_feature_fields(features),
         "predictions": prepare_fields(predictions),
         "rawInputs": None if raw_inputs is None else prepare_fields(raw_inputs),
         "metrics": None if metrics is None else prepare_fields(metrics),
+        "modelDataType": model_data_type,
+        "multiclassLabels": multiclass_labels,
     }
 
     result = await http_client.graphql(query, variables)
@@ -84,6 +94,22 @@ def prepare_fields(fields: Dict[str, str]) -> List[Dict[str, str]]:
     return [{"name": field_name, "type": field_type} for field_name, field_type in fields.items()]
 
 
+def prepare_feature_fields(features: Dict[str, str]) -> List[Dict[str, Union[str, int]]]:
+    """Creates a list of Feature Fields GraphQL objects from a fields dict.
+
+    Args:
+        features: features dict
+
+    Returns:
+        List of GraphQL Field objects.
+    """
+    listed_fields = list(features)
+    return [
+        {"name": field_name, "type": field_type, "vectorPosition": listed_fields.index(field_name)}
+        for field_name, field_type in features.items()
+    ]
+
+
 def validate_fields_input(
     features: Dict[str, str],
     predictions: Dict[str, str],
