@@ -3,7 +3,7 @@ from contextlib import suppress
 from functools import wraps
 from http import HTTPStatus
 import logging
-from typing import Any, Callable, Dict, Optional, Union
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from aporia.model import Model
 from .api.create_model_version import run_create_model_version_query, validate_fields_input
@@ -105,7 +105,12 @@ def init(
         set_log_level(config.debug)
 
         event_loop = EventLoop()
-        http_client = HttpClient(token=config.token, host=config.host, port=config.port, default_timeout=config.http_timeout_seconds)
+        http_client = HttpClient(
+            token=config.token,
+            host=config.host,
+            port=config.port,
+            default_timeout=config.http_timeout_seconds,
+        )
 
         init_context(http_client=http_client, event_loop=event_loop, config=config)
 
@@ -208,6 +213,8 @@ def create_model_version(
     predictions: Dict[str, str],
     raw_inputs: Optional[Dict[str, str]] = None,
     metrics: Optional[Dict[str, str]] = None,
+    model_data_type: Optional[str] = None,
+    multiclass_labels: Optional[List[str]] = None,
 ) -> Optional[Model]:
     """Creates a new model version, and defines a schema for it.
 
@@ -220,6 +227,8 @@ def create_model_version(
         predictions: Schema for prediction results (See notes)
         raw_inputs: Schema for raw inputs (See notes).
         metrics: Schema for prediction metrics (See notes).
+        model_data_type: Model data type.
+        multiclass_labels: Labels of multiclass or binary model
 
     Notes:
         * A schema is a dict, in which the keys are the fields you wish to report, and the
@@ -245,6 +254,9 @@ def create_model_version(
             | "datetime"    | datetime.datetime, or str representing a datetime in ISO-8601 format
             | "vector"      | list of floats
             | "text"        | str (to be used as free text)
+        * The supported data types are:
+            * "tabular"
+            * "nlp"
 
     Returns:
         Model object for the new version.
@@ -255,10 +267,7 @@ def create_model_version(
         raise AporiaError("model_id and model_version must be non-empty strings.")
 
     validate_fields_input(
-        features=features,
-        predictions=predictions,
-        raw_inputs=raw_inputs,
-        metrics=metrics,
+        features=features, predictions=predictions, raw_inputs=raw_inputs, metrics=metrics
     )
 
     context.event_loop.run_coroutine(
@@ -267,10 +276,12 @@ def create_model_version(
             model_id=model_id,
             model_version=model_version,
             model_type=model_type,
+            model_data_type=model_data_type,
             features=features,
             predictions=predictions,
             raw_inputs=raw_inputs,
             metrics=metrics,
+            multiclass_labels=multiclass_labels,
         )
     )
 
