@@ -1,24 +1,23 @@
 import logging
 from typing import Any
 
-from aporia.core.graphql_client import GraphQLClient
+from aporia.core.http_client import HttpClient
 from aporia.core.logging_utils import LOGGER_NAME
 
-
 logger = logging.getLogger(LOGGER_NAME)
 
 
 async def log_json(
-    graphql_client: GraphQLClient, model_id: str, model_version: str, environment: str, data: Any
+    http_client: HttpClient, model_id: str, model_version: str, environment: str, data: Any
 ):
     """Reports arbitrary data.
 
     Args:
-        graphql_client (GraphQLClient): GraphQL client
-        model_id (str): Model ID
-        model_version (str): Model version
-        environment (str): Environment in which aporia SDK is running
-        data (Any): Data to report
+        http_client: Http client
+        model_id: Model ID
+        model_version: Model version
+        environment: Environment in which aporia SDK is running
+        data: Data to report
     """
     query = """
     mutation LogArbitraryData(
@@ -45,6 +44,6 @@ async def log_json(
         "data": data,
     }
 
-    result = await graphql_client.query_with_retries(query, variables)
+    result = await http_client.graphql(query, variables)
     for warning in result["logArbitraryData"]["warnings"]:
         logger.warning(warning)
