@@ -1,4 +1,4 @@
-from collections import abc
+from collections import abc, OrderedDict
 from typing import Dict, Optional, Union
 
 import numpy as np
@@ -137,7 +137,7 @@ def infer_schema_from_dataframe(data: pd.DataFrame) -> Optional[Dict[str, str]]:
                 "cannot infer schema from {}, data must be a pandas DataFrame".format(type(data))
             )
 
-        schema = {}
+        schema = OrderedDict()
         for column_name, values in data.items():
             values_without_nulls = values.dropna().infer_objects()
             column_type = infer_type_from_dtype_and_data(
