@@ -1,5 +1,5 @@
 import logging
-from typing import List, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 from aporia.core.http_client import HttpClient
 from aporia.core.logging_utils import LOGGER_NAME
@@ -205,3 +205,25 @@ async def log_test_data(
     result = await http_client.graphql(query, variables)
     for warning in result["logTestSet"]["warnings"]:
         logger.warning(warning)
+
+
+async def log_training_sample(
+    http_client: HttpClient,
+    model_id: str,
+    model_version: str,
+    features: List[Dict[str, Any]],
+    labels: List[Any],
+):
+    """Reports training sample.
+
+    Args:
+        http_client: Http client
+        model_id: Model ID.
+        model_version: Mode version.
+        features: List of features.
+        labels: List of labels.
+    """
+    await http_client.post(
+        url=f"/models/{model_id}/versions/{model_version}/training_sample",
+        data={"features": features, "labels": labels},
+    )
